@@ -1,23 +1,24 @@
 listWrappers <- function(what = "both") {
+	everything <- sort(getNamespaceExports("SuperLearner"))
 	if(what == "both") {
 		message("All prediction algorithm wrappers in SuperLearner:\n")
-		print(ls("package:SuperLearner", pattern="^[S]L"))
+		print(everything[grepl(pattern="^[S]L", everything)])
 		message("\nAll screening algorithm wrappers in SuperLearner:\n")
 		print("All")
-		print(ls("package:SuperLearner", pattern="screen"))
+		print(everything[grepl(pattern="screen", everything)])
 	} else if(what == "SL") {
 		message("All prediction algorithm wrappers in SuperLearner:\n")
-		print(ls("package:SuperLearner", pattern="^[S]L"))
+		print(everything[grepl(pattern="^[S]L", everything)])
 	} else if(what == "screen") {
 		message("All screening algorithm wrappers in SuperLearner:\n")
 		print("All")
-		print(ls("package:SuperLearner", pattern="screen"))
+		print(everything[grepl(pattern="screen", everything)])
 	} else if(what == 'method') {
 	  message("All methods in SuperLearner package:\n")
-		print(ls("package:SuperLearner", pattern="^method"))
+		print(everything[grepl(pattern="^method", everything)])
 	} else {
 		message("All functions in SuperLearner:\n")
-		print(ls("package:SuperLearner"))
+		print(everything)
 	}
-	invisible(ls("package:SuperLearner"))
-}
\ No newline at end of file
+	invisible(everything)
+}
