@@ -1,3 +1,6 @@
+library(SuperLearner)
+if(all(sapply(c("glmnet"), requireNamespace))) {
+
 ########################
 # Simulate data
 set.seed(23432)
@@ -13,9 +16,11 @@ summary(Y)
 
 ########################
 # Run the SuperLearner
-models = c("SL.randomForest", "SL.glmnet", "SL.glm", "SL.mean")
+models = c("SL.glmnet", "SL.glm", "SL.mean")
 cv_control = SuperLearner.CV.control(V = 2L)
 sl = SuperLearner(Y, X, SL.library = models, cvControl = cv_control)
 sl
 # Check execution times
 sl$times
+
+}
